/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.model;

import org.gradle.api.Incubating;

import java.io.File;

/**
 * Identifies a Gradle build.
 * <p>
 *     A Gradle Build is a collection of one or more projects.
 * </p>
 *
 * @since 2.13
 */
@Incubating
public interface BuildIdentifier extends Model {
    /**
     * The root directory of this build
     *
     * @return the root dir, never null
     * @since 3.3
     */
    File getRootDir();
}
